@@ -1,32 +1,37 @@
-#simple closure store for response data
+#' @importFrom mime guess_type
 res <- local({
   bodyfile <- NULL;
-  headers <- list();  
-  
+  headers <- list();
+  status_ok <- 200L
+
   reset <- function(){
     bodyfile <<- NULL;
     headers <<- list();
     invisible();
   };
-  
-  finish <- function(status=200){
+
+  finish <- function(status = status_ok){
     if(is.null(bodyfile)){
       stop("No body set.")
     }
     resvalue <- list(status=status, headers=headers, body=bodyfile);
     do.call(respond, resvalue);
   };
-  
+
   setbody <- function(text, file){
     if(!missing(file)){
       stopifnot(file.exists(file));
-      bodyfile <<- file;     
+      bodyfile <<- file;
       return(invisible());
-    } 
-    bodyfile <<- utils$write_to_file(text);
+    }
+    bodyfile <<- write_to_file(text);
     invisible();
   };
-  
+
+  setstatus <- function(new_status){
+    status_ok <<- new_status
+  }
+
   setheader <- function(name, value){
     MAXLENGTH = 1000 #truncate long headers
     if(is.character(value) && length(value) > 0){
@@ -40,18 +45,18 @@ res <- local({
     cookiestring = paste(name, "=", value, "; ",sep="")
     setheader("Set-Cookie", cookiestring);
     invisible();
-  }  
-  
+  }
+
   redirect <- function(target, status=302, txt){
     if(missing(txt)){
       setbody(paste("Redirect to", target));
     } else {
       setbody(txt);
-    }    
+    }
     setheader("Location", target);
     finish(status);
   };
-    
+
   redirectpath <- function(subpath, status = 302){
     baseuri <- paste0(req$uri(), req$path_info());
     baseuri <- sub("/$", "", baseuri);
@@ -59,20 +64,20 @@ res <- local({
     fullpath <- paste0(baseuri, "/", subpath);
     redirect(fullpath, status=status);
   }
-  
+
   notfound <- function(filepath, message){
     if(missing(message)){
       if(missing(filepath)){
-        message <- paste("Invalid API call:", req$path_info()) 
+        message <- paste("Invalid API call:", req$path_info())
       } else {
         message <- paste("File not found:", filepath);
       }
     };
     setbody(message);
-    setheader("Content-Type", "text/plain")
+    setheader("Content-Type", "text/plain; charset=utf-8")
     finish(404);
   };
-  
+
   error <- function(msg, status=400){
     setbody(msg);
     finish(status);
@@ -83,66 +88,63 @@ res <- local({
       redirectpath("/")
     }
   };
-  
+
   checkfile <- function(filepath){
     if(!file.exists(filepath)){
       notfound(filepath);
-    }      
+    }
   };
-  
+
   checkmethod <- function(methods = "GET"){
     if(!(req$method() %in% methods)){
       error(paste("Method:", req$method(), "invalid on", req$path_info()), 405);
     }
   }
-  
+
   setcache <- function(what){
     method <- req$method();
     if(method == "POST"){
       cachevalue <- config("httpcache.post");
     } else if(method == "GET"){
       cachevalue <- switch(what,
-        git = config("httpcache.git"),
-        gitapi = config("httpcache.gitapi"),                           
+        apps = config("httpcache.apps"),
         lib = config("httpcache.lib"),
         tmp = config("httpcache.tmp"),
-        cran = config("httpcache.cran"),
-        bioc = config("httpcache.bioc"),                           
-        static = config("httpcache.static"),  
+        static = config("httpcache.static"),
         stop("Setcache called for unknown type: ", what)
       );
     } else {
-      stop("Setcache called for unknown method: ", method);         
+      stop("Setcache called for unknown method: ", method);
     }
-    setheader("Cache-Control", paste("max-age=", cachevalue, ", public", sep=""));    
+    setheader("Cache-Control", paste("max-age=", cachevalue, ", public", sep=""));
   }
-  
+
   listdir <- function(dirpath){
     checkfile(dirpath);
     sendtext(list.files(dirpath));
-    finish(200);
+    finish();
   };
-  
+
   sendlist <- function(vector){
     checktrail();
     vector <- sort(unique(vector));
     sendtext(paste(vector, sep="\n", collapse="\n"));
   }
-        
+
   sendtext <- function(text){
     text <- paste(text, collapse="\n");
     setbody(text);
     setheader("Content-Type", 'text/plain; charset=utf-8')
-    finish(200);
+    finish();
   };
-  
+
   sendhtml <- function(text){
     text <- paste(text, collapse="\n");
     setbody(text);
     setheader("Content-Type", 'text/html; charset=utf-8')
-    finish(200);
-  };  
-  
+    finish();
+  };
+
   sendfile <- function(filepath, mimetype){
     #windows doesn't like trailing slash
     filepath <- sub("/$", "", filepath);
@@ -157,11 +159,11 @@ res <- local({
     }
     bodyfile <<- filepath;
     if(missing(mimetype)){
-      mimetype <- utils$mimetype(filepath);
+      mimetype <- guess_content_type(filepath)
     }
     setheader("Content-Type", mimetype);
-    finish(200);
+    finish();
   };
-  
+
   environment();
-});
\ No newline at end of file
+});
